@@ -9,7 +9,7 @@ use Class::Utils qw(set_params);
 use Error::Pure qw(err);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -143,7 +143,13 @@ L<Error::Pure>.
 
 =head1 SEE ALSO
 
-L<Random::Day>.
+=over
+
+=item L<Random::Day>
+
+Class for random day generation.
+
+=back
 
 =head1 REPOSITORY
 
@@ -157,10 +163,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © Michal Špaček 2013-2014
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
